Module array

Module array 

Functionality relating to the JSON array type

Structs

IArray
The IArray type is similar to a Vec<IValue>. The primary difference is that the length and capacity are stored inside the heap allocation, so that the IArray itself can be a single pointer.
IntoIter
Iterator over IValues returned from IArray::into_iter