Functionality relating to the JSON array type
Structs
- IArray
- The
IArraytype is similar to aVec<IValue>. The primary difference is that the length and capacity are stored inside the heap allocation, so that theIArrayitself can be a single pointer. - Into
Iter - Iterator over
IValues returned fromIArray::into_iter